.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    sab 08 nov 2008 20:43:11 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

=============
 SoL modules
=============

.. toctree::
   :maxdepth: 2

   i18n
   models
   printouts
   views
